package schedule
import "github.com/coreos/etcd/pkg/schedule"
Index ¶
Types ¶
type Job ¶
type Scheduler ¶
type Scheduler interface {
// Schedule asks the scheduler to schedule a job defined by the given func.
// Schedule to a stopped scheduler might panic.
Schedule(j Job)
// Pending returns number of pending jobs
Pending() int
// Scheduled returns the number of scheduled jobs (excluding pending jobs)
Scheduled() int
// Finished returns the number of finished jobs
Finished() int
// WaitFinish waits until at least n job are finished and all pending jobs are finished.
WaitFinish(n int)
// Stop stops the scheduler.
Stop()
}
Scheduler can schedule jobs.
func NewFIFOScheduler ¶
func NewFIFOScheduler() Scheduler
NewFIFOScheduler returns a Scheduler that schedules jobs in FIFO order sequentially
Source Files ¶
- Version
- v2.3.8+incompatible (latest)
- Published
- Feb 16, 2017
- Platform
- linux/amd64
- Imports
- 2 packages
- Last checked
- 1 week ago –
Tools for package owners.