package wait
import "github.com/coreos/etcd/pkg/wait"
Package wait provides utility functions for polling, listening using Go channel.
Index ¶
- func NewTimeList() *timeList
- type List
- func New() *List
- func (w *List) Register(id uint64) <-chan interface{}
- func (w *List) Trigger(id uint64, x interface{})
- type Wait
- type WaitTime
Functions ¶
func NewTimeList ¶
func NewTimeList() *timeList
Types ¶
type List ¶
type List struct {
// contains filtered or unexported fields
}
func New ¶
func New() *List
func (*List) Register ¶
func (*List) Trigger ¶
type Wait ¶
func NewWithResponse ¶
func NewWithResponse(ch <-chan interface{}) Wait
type WaitTime ¶
type WaitTime interface {
// Wait returns a chan that waits on the given deadline.
// The chan will be triggered when Trigger is called with a
// deadline that is later than the one it is waiting for.
// The given deadline MUST be unique. The deadline should be
// retrieved by calling time.Now() in most cases.
Wait(deadline time.Time) <-chan struct{}
// Trigger triggers all the waiting chans with an earlier deadline.
Trigger(deadline time.Time)
}
Source Files ¶
- Version
- v2.3.8+incompatible (latest)
- Published
- Feb 16, 2017
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 1 week ago –
Tools for package owners.