package client
import "github.com/coreos/etcd/tools/functional-tester/etcd-agent/client"
Index ¶
Types ¶
type Agent ¶
type Agent interface {
ID() uint64
// Start starts a new etcd with the given args on the agent machine.
Start(args ...string) (int, error)
// Stop stops the existing etcd the agent started.
Stop() error
// Restart restarts the existing etcd the agent stopped.
Restart() (int, error)
// Cleanup stops the exiting etcd the agent started, then archives log and its data dir.
Cleanup() error
// Terminate stops the exiting etcd the agent started and removes its data dir.
Terminate() error
// DropPort drops all network packets at the given port.
DropPort(port int) error
// RecoverPort stops dropping all network packets at the given port.
RecoverPort(port int) error
// Status returns the status of etcd on the agent
Status() (Status, error)
}
func NewAgent ¶
type Status ¶
type Status struct {
// TODO: gather more informations
// TODO: memory usage, raft information, etc..
State string
}
Source Files ¶
- Version
- v2.3.8+incompatible (latest)
- Published
- Feb 16, 2017
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 1 week ago –
Tools for package owners.